@@ -127,8 +127,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -150,9 +150,9 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        domain_name: str,
+        domain_name: builtins.str,
         dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
@@ -190,42 +190,42 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
 
         jsii.create(DynamoDBStreamToLambdaToElasticSearchAndKibana, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(self) -> typing.List[aws_cdk.aws_cloudwatch.Alarm]:
         return jsii.get(self, "cloudwatchAlarms")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> aws_cdk.aws_dynamodb.Table:
         return jsii.get(self, "dynamoTable")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="elasticsearchDomain")
     def elasticsearch_domain(self) -> aws_cdk.aws_elasticsearch.CfnDomain:
         return jsii.get(self, "elasticsearchDomain")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="elasticsearchRole")
     def elasticsearch_role(self) -> aws_cdk.aws_iam.Role:
         return jsii.get(self, "elasticsearchRole")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="identityPool")
     def identity_pool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
         return jsii.get(self, "identityPool")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="userPool")
     def user_pool(self) -> aws_cdk.aws_cognito.UserPool:
         return jsii.get(self, "userPool")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="userPoolClient")
     def user_pool_client(self) -> aws_cdk.aws_cognito.UserPoolClient:
         return jsii.get(self, "userPoolClient")
@@ -248,7 +248,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
     def __init__(
         self,
         *,
-        domain_name: str,
+        domain_name: builtins.str,
         dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
@@ -276,7 +276,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
             es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
         }
         if dynamo_event_source_props is not None:
@@ -293,13 +293,15 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
             self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
-    def domain_name(self) -> str:
+    def domain_name(self) -> builtins.str:
         """Cognito & ES Domain Name.
 
         default
         :default: - None
         """
-        return self._values.get("domain_name")
+        result = self._values.get("domain_name")
+        assert result is not None, "Required property 'domain_name' is missing"
+        return result
 
     @builtins.property
     def dynamo_event_source_props(
@@ -310,7 +312,8 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("dynamo_event_source_props")
+        result = self._values.get("dynamo_event_source_props")
+        return result
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
@@ -319,7 +322,8 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("dynamo_table_props")
+        result = self._values.get("dynamo_table_props")
+        return result
 
     @builtins.property
     def es_domain_props(
@@ -330,7 +334,8 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("es_domain_props")
+        result = self._values.get("es_domain_props")
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -339,7 +344,8 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -348,7 +354,8 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         default
         :default: - None
         """
-        return self._values.get("existing_table_obj")
+        result = self._values.get("existing_table_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -359,12 +366,13 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
